@@ -1,4 +1,4 @@
-## ------------------------------------------------------------------------
+## ----warning=FALSE,message=FALSE-----------------------------------------
 knit_by_pkgdown <- !is.null(knitr::opts_chunk$get("fig.retina"))
 knitr::opts_chunk$set(warning = TRUE, message = TRUE, error = FALSE)
 pander::panderOptions("table.split.table", Inf)
@@ -6,6 +6,12 @@ ggplot2::theme_set(ggplot2::theme_bw())
 
 library(codebook)
 data("bfi", package = 'codebook')
+if (!knit_by_pkgdown) {
+  library(dplyr)
+    bfi <- bfi %>% select(-starts_with("BFIK_extra"),
+                        -starts_with("BFIK_open"),
+                        -starts_with("BFIK_consc"))
+}
 set.seed(1)
 bfi$age <- rpois(nrow(bfi), 30)
 library(labelled)
@@ -154,8 +160,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -171,9 +177,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -204,32 +212,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -251,8 +275,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -268,9 +292,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -301,32 +327,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -342,298 +384,7 @@ escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
-	indent <- '#'
-}
-if (exists("testing")) {
-  scale_name <- safe_name <- "bla"
-	scale <- 1:10
-	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
-}
-html_scale_name <- recursive_escape(scale_name)
-names(items) <- recursive_escape(names(items))
-scale_info <- recursive_escape(attributes(scale))
-
-## ----likert_setup--------------------------------------------------------
-old_height <- knitr::opts_chunk$get("fig.height")
-new_height <- length(scale_info$scale_item_names)
-new_height <- ifelse(new_height > 20, 20, new_height)
-new_height <- ifelse(new_height < 1, 1, new_height)
-new_height <- ifelse(is.na(new_height) | is.nan(new_height), 
-                     old_height, new_height)
-knitr::opts_chunk$set(fig.height = new_height)
-
-## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
-}
-knitr::opts_chunk$set(fig.height = old_height)
-
-## ----setup_distribution--------------------------------------------------
-binwidth <- mean(diff(sort(unique(scale))))
-
-wrap_at <- knitr::opts_chunk$get("fig.width") * 10
-
-## ----distribution--------------------------------------------------------
-dist_plot <- plot_labelled(scale, scale_name, wrap_at)
-
-choices <- attributes(items[[1]])$item$choices
-breaks <- as.numeric(names(choices))
-if (length(breaks)) {
-  suppressMessages( # ignore message about overwriting x axis
-  dist_plot <- dist_plot +
-    	ggplot2::scale_x_continuous("values", 
-	                            breaks = breaks, 
-	                            labels = stringr::str_wrap(unlist(choices), ceiling(wrap_at * 0.21))) +
-      ggplot2::expand_limits(x = range(breaks)))
-  
-}
-
-dist_plot
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
-## ----summary-------------------------------------------------------------
-for (i in seq_along(names(items))) {
-  attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
-}
-escaped_table(codebook_table(items))
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent <- '#'
-}
-if (exists("testing")) {
-  scale_name <- safe_name <- "bla"
-	scale <- 1:10
-	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
-}
-html_scale_name <- recursive_escape(scale_name)
-names(items) <- recursive_escape(names(items))
-scale_info <- recursive_escape(attributes(scale))
-
-## ----likert_setup--------------------------------------------------------
-old_height <- knitr::opts_chunk$get("fig.height")
-new_height <- length(scale_info$scale_item_names)
-new_height <- ifelse(new_height > 20, 20, new_height)
-new_height <- ifelse(new_height < 1, 1, new_height)
-new_height <- ifelse(is.na(new_height) | is.nan(new_height), 
-                     old_height, new_height)
-knitr::opts_chunk$set(fig.height = new_height)
-
-## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
-}
-knitr::opts_chunk$set(fig.height = old_height)
-
-## ----setup_distribution--------------------------------------------------
-binwidth <- mean(diff(sort(unique(scale))))
-
-wrap_at <- knitr::opts_chunk$get("fig.width") * 10
-
-## ----distribution--------------------------------------------------------
-dist_plot <- plot_labelled(scale, scale_name, wrap_at)
-
-choices <- attributes(items[[1]])$item$choices
-breaks <- as.numeric(names(choices))
-if (length(breaks)) {
-  suppressMessages( # ignore message about overwriting x axis
-  dist_plot <- dist_plot +
-    	ggplot2::scale_x_continuous("values", 
-	                            breaks = breaks, 
-	                            labels = stringr::str_wrap(unlist(choices), ceiling(wrap_at * 0.21))) +
-      ggplot2::expand_limits(x = range(breaks)))
-  
-}
-
-dist_plot
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
-## ----summary-------------------------------------------------------------
-for (i in seq_along(names(items))) {
-  attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
-}
-escaped_table(codebook_table(items))
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent <- '#'
-}
-if (exists("testing")) {
-  scale_name <- safe_name <- "bla"
-	scale <- 1:10
-	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
-}
-html_scale_name <- recursive_escape(scale_name)
-names(items) <- recursive_escape(names(items))
-scale_info <- recursive_escape(attributes(scale))
-
-## ----likert_setup--------------------------------------------------------
-old_height <- knitr::opts_chunk$get("fig.height")
-new_height <- length(scale_info$scale_item_names)
-new_height <- ifelse(new_height > 20, 20, new_height)
-new_height <- ifelse(new_height < 1, 1, new_height)
-new_height <- ifelse(is.na(new_height) | is.nan(new_height), 
-                     old_height, new_height)
-knitr::opts_chunk$set(fig.height = new_height)
-
-## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
-}
-knitr::opts_chunk$set(fig.height = old_height)
-
-## ----setup_distribution--------------------------------------------------
-binwidth <- mean(diff(sort(unique(scale))))
-
-wrap_at <- knitr::opts_chunk$get("fig.width") * 10
-
-## ----distribution--------------------------------------------------------
-dist_plot <- plot_labelled(scale, scale_name, wrap_at)
-
-choices <- attributes(items[[1]])$item$choices
-breaks <- as.numeric(names(choices))
-if (length(breaks)) {
-  suppressMessages( # ignore message about overwriting x axis
-  dist_plot <- dist_plot +
-    	ggplot2::scale_x_continuous("values", 
-	                            breaks = breaks, 
-	                            labels = stringr::str_wrap(unlist(choices), ceiling(wrap_at * 0.21))) +
-      ggplot2::expand_limits(x = range(breaks)))
-  
-}
-
-dist_plot
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent = ''
-}
-if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
-}
-
-## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
-}
-
-## ------------------------------------------------------------------------
-pander::pander(x$total)
-
-## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
-
-## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
-
-## ----reliability, results='asis'-----------------------------------------
-for (i in seq_along(reliabilities)) {
-  rel <- reliabilities[[i]]
-  cat(knitr::knit_print(rel, indent = paste0(indent, "####")))
-}
-
-## ----summary-------------------------------------------------------------
-for (i in seq_along(names(items))) {
-  attributes(items[[i]]) = recursive_escape(attributes(items[[i]]))
-}
-escaped_table(codebook_table(items))
-
-## ----setup,eval=TRUE,echo=FALSE------------------------------------------
-if (!exists("indent")) {
-	indent <- '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
+	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
 if (exists("testing")) {
 	item <- 1:10
@@ -641,7 +392,8 @@ if (exists("testing")) {
 	attributes(item) <- list(label = 'yayya')
 }
 
-item_attributes <- recursive_escape(attributes(item))
+item_attributes <- attributes(item)
+item_attributes <- recursive_escape(item_attributes)
 html_item_name <- recursive_escape(item_name)
 item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label), 
                      "", item_attributes$label)
@@ -671,6 +423,7 @@ item_nomiss <- item[!is.na(item)]
 if (
   is.character(item_nomiss) &&
   any(stringr::str_detect(item_nomiss, stringr::fixed(", "))) &&
+  !is.null(item_info) &&
   (exists("type", item_info) && 
     any(stringr::str_detect(item_info$type, 
                             pattern = stringr::fixed("multiple"))))
@@ -682,7 +435,8 @@ attributes(item_nomiss) <- attributes(item)
 old_height <- knitr::opts_chunk$get("fig.height")
 non_missing_choices <- item_attributes[["labels"]]
 many_labels <- length(non_missing_choices) > 7
-go_vertical <- !is.numeric(item_nomiss) || many_labels
+go_vertical <- !is_numeric_or_time_var(item_nomiss) || many_labels
+  
 if ( go_vertical ) {
   # numeric items are plotted horizontally (because that's what usually expected)
   # categorical items are plotted vertically because we can use the screen real estate better this way
@@ -696,6 +450,9 @@ if ( go_vertical ) {
 	new_height <- 2 + choice_multiplier * length(non_missing_choices)
 	new_height <- ifelse(new_height > 20, 20, new_height)
 	new_height <- ifelse(new_height < 1, 1, new_height)
+	if(could_disclose_unique_values(item_nomiss) && is.character(item_nomiss)) {
+	  new_height <- old_height
+	}
 	knitr::opts_chunk$set(fig.height = new_height)
 }
 
@@ -707,10 +464,17 @@ wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 # todo: bin rare responses into "other category"
 if (!length(item_nomiss)) {
   cat("No non-missing values to show.")
-} else if (is.numeric(item_nomiss) || dplyr::n_distinct(item_nomiss) < 20) {
+} else if (!could_disclose_unique_values(item_nomiss)) {
   plot_labelled(item_nomiss, item_name, wrap_at, go_vertical)
 } else {
-	cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  if (is.character(item_nomiss)) {
+      char_count <- stringr::str_count(item_nomiss)
+      attributes(char_count)$label <- item_label
+      plot_labelled(char_count, 
+                    item_name, wrap_at, FALSE, trans = "log1p", "characters")
+  } else {
+	  cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -755,11 +519,6 @@ if (exists("testing")) {
 }
 
 ## ----missingness_all_setup-----------------------------------------------
-if (!exists("ended", results) ||
-  !exists("expired", results)) {
-  warning("Could not figure out who finished the surveys, because the ",
-          "variables expired and ended were missing.")
-}
 if (length(md_pattern)) {
   if (knitr::is_html_output()) {
     rmarkdown::paged_table(md_pattern, options = list(rows.print = 10))
@@ -772,7 +531,9 @@ if (length(md_pattern)) {
 if (exists("testing")) {
 	indent = '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
 	results = data.frame()
+	jsonld_metadata <- list(test = 1)
 }
+json <- jsonlite::toJSON(jsonld_metadata, pretty = TRUE, auto_unbox = TRUE)
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
@@ -786,6 +547,8 @@ if (exists("testing")) {
 	data_info <- '' 
 	survey_overview <- '' 
 	scales_items <- c()
+	detailed_items <- TRUE
+	detailed_scales <- TRUE
 }
 
 ## ------------------------------------------------------------------------
@@ -795,7 +558,9 @@ knitr::asis_output(data_info)
 knitr::asis_output(survey_overview)
 
 ## ----scales--------------------------------------------------------------
-knitr::asis_output(paste0(scales_items, sep = "\n\n\n", collapse = "\n\n\n"))
+if (detailed_variables || detailed_scales) {
+  knitr::asis_output(paste0(scales_items, sep = "\n\n\n", collapse = "\n\n\n"))
+}
 
 ## ------------------------------------------------------------------------
 missingness_report
