@@ -121,24 +121,24 @@ codebook_data <- detect_scales(codebook_data)
 
 
 
-## ---- eval = FALSE-------------------------------------------------------
-#  metadata(codebook_data)$name <- "25 Personality items representing 5 factors"
-#  metadata(codebook_data)$description <- "25 personality self report items taken from the International Personality Item Pool (ipip.ori.org)[...]"
+## ------------------------------------------------------------------------
+metadata(codebook_data)$name <- "25 Personality items representing 5 factors"
+metadata(codebook_data)$description <- "25 personality self report items taken from the International Personality Item Pool (ipip.ori.org)[...]"
 
-## ---- eval = FALSE-------------------------------------------------------
-#  metadata(codebook_data)$identifier <- "https://dx.doi.org/10.17605/OSF.IO/K39BG"
+## ------------------------------------------------------------------------
+metadata(codebook_data)$identifier <- "https://dx.doi.org/10.17605/OSF.IO/K39BG"
+
+## ------------------------------------------------------------------------
+metadata(codebook_data)$creator <- "William Revelle"
+metadata(codebook_data)$citation <- "Revelle, W., Wilt, J., and Rosenthal, A. (2010) Individual Differences in Cognition: New Methods for examining the Personality-Cognition Link In Gruszka, A. and Matthews, G. and Szymura, B. (Eds.) Handbook of Individual Differences in Cognition: Attention, Memory and Executive Control, Springer."
+metadata(codebook_data)$url <- "https://CRAN.R-project.org/package=psych"
+
+## ------------------------------------------------------------------------
+metadata(codebook_data)$datePublished <- "2010-01-01"
+metadata(codebook_data)$temporalCoverage <- "Spring 2010" 
+metadata(codebook_data)$spatialCoverage <- "Online"
 
-## ---- eval = FALSE-------------------------------------------------------
-#  metadata(codebook_data)$creator <- "William Revelle"
-#  metadata(codebook_data)$citation <- "Revelle, W., Wilt, J., and Rosenthal, A. (2010) Individual Differences in Cognition: New Methods for examining the Personality-Cognition Link In Gruszka, A. and Matthews, G. and Szymura, B. (Eds.) Handbook of Individual Differences in Cognition: Attention, Memory and Executive Control, Springer."
-#  metadata(codebook_data)$url <- "https://cran.r-project.org/web/packages/psych/index.html"
 
-## ---- eval = FALSE-------------------------------------------------------
-#  metadata(codebook_data)$datePublished <- "2010-01-01"
-#  metadata(codebook_data)$temporalCoverage <- "Spring 2010"
-#  metadata(codebook_data)$spatialCoverage <- "Online"
-#  
-#  
 
 ## ----eval=FALSE----------------------------------------------------------
 #  rio::export(codebook_data, "bfi.rds") # to R data structure file
@@ -239,8 +239,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -256,9 +256,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -289,32 +291,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -336,8 +354,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -353,9 +371,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -386,32 +406,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -433,8 +469,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -450,9 +486,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -483,32 +521,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -530,8 +584,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -547,9 +601,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -580,32 +636,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -627,8 +699,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -644,9 +716,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -677,32 +751,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -724,8 +814,8 @@ if (exists("testing")) {
   scale_name <- safe_name <- "bla"
 	scale <- 1:10
 	reliabilities <- list()
-	items <- list()
-	scale_info <- list(scale_item_names = c("item1", "item2", "item3R"))
+	items <- data.frame(bla1 = 1:10, bla2 = 1:10, bla3R = 10:1)
+	scale_info <- list(scale_item_names = c("bla1", "bla2", "bla3R"))
 }
 html_scale_name <- recursive_escape(scale_name)
 names(items) <- recursive_escape(names(items))
@@ -741,9 +831,11 @@ new_height <- ifelse(is.na(new_height) | is.nan(new_height),
 knitr::opts_chunk$set(fig.height = new_height)
 
 ## ----likert--------------------------------------------------------------
-likert_plot <- likert_from_items(items)
-if (!is.null(likert_plot)) {
-  graphics::plot(likert_plot)
+if (dplyr::n_distinct(na.omit(unlist(items))) < 12) {
+  likert_plot <- likert_from_items(items)
+  if (!is.null(likert_plot)) {
+    graphics::plot(likert_plot)
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -774,32 +866,48 @@ if (!exists("indent")) {
 	indent = ''
 }
 if (exists("testing")) {
-	example("alpha", "psych")
-  x = a4
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_open_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = FALSE)
+	testDat <- bfi %>% dplyr::select(dplyr::starts_with("BFIK_consc_"))
+  x = userfriendlyscience::scaleDiagnosis(testDat, 
+                                          scaleReliability.ci = TRUE)
 }
 
 ## ------------------------------------------------------------------------
-if (!is.null(x$total$ase)) {
-  pander::pander(data.frame(lower = x$total$raw_alpha - 1.96 * x$total$ase, 
-             estimate = x$total$raw_alpha, 
-             upper = x$total$raw_alpha + 1.96 * 
-  x$total$ase))
+coefs <- x$scaleReliability$output$dat %>% 
+  tidyr::gather(index, estimate) %>% 
+  dplyr::filter(index != "n.items", index != "n.observations") %>% 
+  dplyr::mutate(index = stringr::str_to_title(
+    stringr::str_replace_all(index,
+      stringr::fixed("."), " ")))
+
+cis <- coefs %>% 
+  dplyr::filter(stringr::str_detect(index, " Ci ")) %>% 
+  tidyr::separate(index, c("index", "hilo"), sep = " Ci ") %>% 
+  tidyr::spread(hilo, estimate)
+if (nrow(cis)) {
+  cis <- cis %>% dplyr::rename(
+    `Lower 95% CI` = .data$Lo, `Upper 95% CI` = .data$Hi
+  )
 }
 
-## ------------------------------------------------------------------------
-pander::pander(x$total)
+coefs_with_cis <- coefs %>% 
+  dplyr::filter(!stringr::str_detect(index, " Ci ")) %>% 
+    dplyr::left_join(cis, by = "index") %>% 
+    dplyr::mutate(index = dplyr::if_else(index == "Glb", "Greatest Lower Bound", .data$index)) %>% 
+    dplyr::arrange(!stringr::str_detect(index, "Omega")) %>% 
+    dplyr::select(Index = .data$index, Estimate = .data$estimate)
+
+
+pander::pander(coefs_with_cis)
 
 ## ------------------------------------------------------------------------
-rownames(x$alpha.drop) <- recursive_escape(rownames(x$alpha.drop))
-pander::pander(x$alpha.drop)
+print(x$scatterMatrix$output$scatterMatrix)
+x$scatterMatrix$output$scatterMatrix <- no_md()
 
 ## ------------------------------------------------------------------------
-rownames(x$item.stats) <- recursive_escape(rownames(x$item.stats))
-pander::pander(x$item.stats)
-
-## ------------------------------------------------------------------------
-rownames(x$response.freq) <- recursive_escape(rownames(x$response.freq))
-pander::pander(x$response.freq)
+print(x)
 
 ## ----reliability, results='asis'-----------------------------------------
 for (i in seq_along(reliabilities)) {
@@ -815,7 +923,7 @@ escaped_table(codebook_table(items))
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
-	indent <- '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
+	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
 if (exists("testing")) {
 	item <- 1:10
@@ -823,7 +931,8 @@ if (exists("testing")) {
 	attributes(item) <- list(label = 'yayya')
 }
 
-item_attributes <- recursive_escape(attributes(item))
+item_attributes <- attributes(item)
+item_attributes <- recursive_escape(item_attributes)
 html_item_name <- recursive_escape(item_name)
 item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label), 
                      "", item_attributes$label)
@@ -853,6 +962,7 @@ item_nomiss <- item[!is.na(item)]
 if (
   is.character(item_nomiss) &&
   any(stringr::str_detect(item_nomiss, stringr::fixed(", "))) &&
+  !is.null(item_info) &&
   (exists("type", item_info) && 
     any(stringr::str_detect(item_info$type, 
                             pattern = stringr::fixed("multiple"))))
@@ -864,7 +974,8 @@ attributes(item_nomiss) <- attributes(item)
 old_height <- knitr::opts_chunk$get("fig.height")
 non_missing_choices <- item_attributes[["labels"]]
 many_labels <- length(non_missing_choices) > 7
-go_vertical <- !is.numeric(item_nomiss) || many_labels
+go_vertical <- !is_numeric_or_time_var(item_nomiss) || many_labels
+  
 if ( go_vertical ) {
   # numeric items are plotted horizontally (because that's what usually expected)
   # categorical items are plotted vertically because we can use the screen real estate better this way
@@ -878,6 +989,9 @@ if ( go_vertical ) {
 	new_height <- 2 + choice_multiplier * length(non_missing_choices)
 	new_height <- ifelse(new_height > 20, 20, new_height)
 	new_height <- ifelse(new_height < 1, 1, new_height)
+	if(could_disclose_unique_values(item_nomiss) && is.character(item_nomiss)) {
+	  new_height <- old_height
+	}
 	knitr::opts_chunk$set(fig.height = new_height)
 }
 
@@ -889,10 +1003,17 @@ wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 # todo: bin rare responses into "other category"
 if (!length(item_nomiss)) {
   cat("No non-missing values to show.")
-} else if (is.numeric(item_nomiss) || dplyr::n_distinct(item_nomiss) < 20) {
+} else if (!could_disclose_unique_values(item_nomiss)) {
   plot_labelled(item_nomiss, item_name, wrap_at, go_vertical)
 } else {
-	cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  if (is.character(item_nomiss)) {
+      char_count <- stringr::str_count(item_nomiss)
+      attributes(char_count)$label <- item_label
+      plot_labelled(char_count, 
+                    item_name, wrap_at, FALSE, trans = "log1p", "characters")
+  } else {
+	  cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -927,7 +1048,7 @@ if (!is.null(choices) && length(choices) && length(choices) < 30) {
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
-	indent <- '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
+	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
 if (exists("testing")) {
 	item <- 1:10
@@ -935,7 +1056,8 @@ if (exists("testing")) {
 	attributes(item) <- list(label = 'yayya')
 }
 
-item_attributes <- recursive_escape(attributes(item))
+item_attributes <- attributes(item)
+item_attributes <- recursive_escape(item_attributes)
 html_item_name <- recursive_escape(item_name)
 item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label), 
                      "", item_attributes$label)
@@ -965,6 +1087,7 @@ item_nomiss <- item[!is.na(item)]
 if (
   is.character(item_nomiss) &&
   any(stringr::str_detect(item_nomiss, stringr::fixed(", "))) &&
+  !is.null(item_info) &&
   (exists("type", item_info) && 
     any(stringr::str_detect(item_info$type, 
                             pattern = stringr::fixed("multiple"))))
@@ -976,7 +1099,8 @@ attributes(item_nomiss) <- attributes(item)
 old_height <- knitr::opts_chunk$get("fig.height")
 non_missing_choices <- item_attributes[["labels"]]
 many_labels <- length(non_missing_choices) > 7
-go_vertical <- !is.numeric(item_nomiss) || many_labels
+go_vertical <- !is_numeric_or_time_var(item_nomiss) || many_labels
+  
 if ( go_vertical ) {
   # numeric items are plotted horizontally (because that's what usually expected)
   # categorical items are plotted vertically because we can use the screen real estate better this way
@@ -990,6 +1114,9 @@ if ( go_vertical ) {
 	new_height <- 2 + choice_multiplier * length(non_missing_choices)
 	new_height <- ifelse(new_height > 20, 20, new_height)
 	new_height <- ifelse(new_height < 1, 1, new_height)
+	if(could_disclose_unique_values(item_nomiss) && is.character(item_nomiss)) {
+	  new_height <- old_height
+	}
 	knitr::opts_chunk$set(fig.height = new_height)
 }
 
@@ -1001,10 +1128,17 @@ wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 # todo: bin rare responses into "other category"
 if (!length(item_nomiss)) {
   cat("No non-missing values to show.")
-} else if (is.numeric(item_nomiss) || dplyr::n_distinct(item_nomiss) < 20) {
+} else if (!could_disclose_unique_values(item_nomiss)) {
   plot_labelled(item_nomiss, item_name, wrap_at, go_vertical)
 } else {
-	cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  if (is.character(item_nomiss)) {
+      char_count <- stringr::str_count(item_nomiss)
+      attributes(char_count)$label <- item_label
+      plot_labelled(char_count, 
+                    item_name, wrap_at, FALSE, trans = "log1p", "characters")
+  } else {
+	  cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -1039,7 +1173,7 @@ if (!is.null(choices) && length(choices) && length(choices) < 30) {
 
 ## ----setup,eval=TRUE,echo=FALSE------------------------------------------
 if (!exists("indent")) {
-	indent <- '#' # ugly hack so _regression_summary can be "spun" (variables included via `r ` have to be available)
+	indent <- '#' # ugly hack so it can be "spun" (variables included via `r ` have to be available)
 }
 if (exists("testing")) {
 	item <- 1:10
@@ -1047,7 +1181,8 @@ if (exists("testing")) {
 	attributes(item) <- list(label = 'yayya')
 }
 
-item_attributes <- recursive_escape(attributes(item))
+item_attributes <- attributes(item)
+item_attributes <- recursive_escape(item_attributes)
 html_item_name <- recursive_escape(item_name)
 item_label <- ifelse(is.null(item_attributes) || is.null(item_attributes$label), 
                      "", item_attributes$label)
@@ -1077,6 +1212,7 @@ item_nomiss <- item[!is.na(item)]
 if (
   is.character(item_nomiss) &&
   any(stringr::str_detect(item_nomiss, stringr::fixed(", "))) &&
+  !is.null(item_info) &&
   (exists("type", item_info) && 
     any(stringr::str_detect(item_info$type, 
                             pattern = stringr::fixed("multiple"))))
@@ -1088,7 +1224,8 @@ attributes(item_nomiss) <- attributes(item)
 old_height <- knitr::opts_chunk$get("fig.height")
 non_missing_choices <- item_attributes[["labels"]]
 many_labels <- length(non_missing_choices) > 7
-go_vertical <- !is.numeric(item_nomiss) || many_labels
+go_vertical <- !is_numeric_or_time_var(item_nomiss) || many_labels
+  
 if ( go_vertical ) {
   # numeric items are plotted horizontally (because that's what usually expected)
   # categorical items are plotted vertically because we can use the screen real estate better this way
@@ -1102,6 +1239,9 @@ if ( go_vertical ) {
 	new_height <- 2 + choice_multiplier * length(non_missing_choices)
 	new_height <- ifelse(new_height > 20, 20, new_height)
 	new_height <- ifelse(new_height < 1, 1, new_height)
+	if(could_disclose_unique_values(item_nomiss) && is.character(item_nomiss)) {
+	  new_height <- old_height
+	}
 	knitr::opts_chunk$set(fig.height = new_height)
 }
 
@@ -1113,10 +1253,17 @@ wrap_at <- knitr::opts_chunk$get("fig.width") * 10
 # todo: bin rare responses into "other category"
 if (!length(item_nomiss)) {
   cat("No non-missing values to show.")
-} else if (is.numeric(item_nomiss) || dplyr::n_distinct(item_nomiss) < 20) {
+} else if (!could_disclose_unique_values(item_nomiss)) {
   plot_labelled(item_nomiss, item_name, wrap_at, go_vertical)
 } else {
-	cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  if (is.character(item_nomiss)) {
+      char_count <- stringr::str_count(item_nomiss)
+      attributes(char_count)$label <- item_label
+      plot_labelled(char_count, 
+                    item_name, wrap_at, FALSE, trans = "log1p", "characters")
+  } else {
+	  cat(dplyr::n_distinct(item_nomiss), " unique, categorical values, so not shown.")
+  }
 }
 knitr::opts_chunk$set(fig.height = old_height)
 
@@ -1161,11 +1308,6 @@ if (exists("testing")) {
 }
 
 ## ----missingness_all_setup-----------------------------------------------
-if (!exists("ended", results) ||
-  !exists("expired", results)) {
-  warning("Could not figure out who finished the surveys, because the ",
-          "variables expired and ended were missing.")
-}
 if (length(md_pattern)) {
   if (knitr::is_html_output()) {
     rmarkdown::paged_table(md_pattern, options = list(rows.print = 10))
@@ -1186,6 +1328,8 @@ if (exists("testing")) {
 	data_info <- '' 
 	survey_overview <- '' 
 	scales_items <- c()
+	detailed_items <- TRUE
+	detailed_scales <- TRUE
 }
 
 ## ------------------------------------------------------------------------
@@ -1195,7 +1339,9 @@ knitr::asis_output(data_info)
 knitr::asis_output(survey_overview)
 
 ## ----scales--------------------------------------------------------------
-knitr::asis_output(paste0(scales_items, sep = "\n\n\n", collapse = "\n\n\n"))
+if (detailed_variables || detailed_scales) {
+  knitr::asis_output(paste0(scales_items, sep = "\n\n\n", collapse = "\n\n\n"))
+}
 
 ## ------------------------------------------------------------------------
 missingness_report
